==> openshift-model-console-6.3.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyServiceFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsolePluginProxyServiceFluentImpl<A extends ConsolePluginProxyServiceFluent<A>> extends BaseFluent<A> implements ConsolePluginProxyServiceFluent<A>{
  public ConsolePluginProxyServiceFluentImpl() {
  }
  public ConsolePluginProxyServiceFluentImpl(ConsolePluginProxyService instance) {
    this.withAuthorize(instance.getAuthorize()); 
    this.withCaCertificate(instance.getCaCertificate()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPort(instance.getPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Boolean authorize;
  private String caCertificate;
  private String name;
  private String namespace;
  private Integer port;
  private Map<String,Object> additionalProperties;
  public Boolean getAuthorize() {
    return this.authorize;
  }
  public A withAuthorize(Boolean authorize) {
    this.authorize=authorize; return (A) this;
  }
  public Boolean hasAuthorize() {
    return this.authorize != null;
  }
  public String getCaCertificate() {
    return this.caCertificate;
  }
  public A withCaCertificate(String caCertificate) {
    this.caCertificate=caCertificate; return (A) this;
  }
  public Boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginProxyServiceFluentImpl that = (ConsolePluginProxyServiceFluentImpl) o;
    if (authorize != null ? !authorize.equals(that.authorize) :that.authorize != null) return false;
    if (caCertificate != null ? !caCertificate.equals(that.caCertificate) :that.caCertificate != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authorize,  caCertificate,  name,  namespace,  port,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authorize != null) { sb.append("authorize:"); sb.append(authorize + ","); }
    if (caCertificate != null) { sb.append("caCertificate:"); sb.append(caCertificate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withAuthorize() {
    return withAuthorize(true);
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyServiceFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsolePluginProxyServiceFluentImpl<A extends ConsolePluginProxyServiceFluent<A>> extends BaseFluent<A> implements ConsolePluginProxyServiceFluent<A>{
  public ConsolePluginProxyServiceFluentImpl() {
  }
  public ConsolePluginProxyServiceFluentImpl(ConsolePluginProxyService instance) {
    if (instance != null) {
      this.withAuthorize(instance.getAuthorize());
      this.withCaCertificate(instance.getCaCertificate());
      this.withName(instance.getName());
      this.withNamespace(instance.getNamespace());
      this.withPort(instance.getPort());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean authorize;
  private String caCertificate;
  private String name;
  private String namespace;
  private Integer port;
  private Map<String,Object> additionalProperties;
  public Boolean getAuthorize() {
    return this.authorize;
  }
  public A withAuthorize(Boolean authorize) {
    this.authorize=authorize; return (A) this;
  }
  public Boolean hasAuthorize() {
    return this.authorize != null;
  }
  public String getCaCertificate() {
    return this.caCertificate;
  }
  public A withCaCertificate(String caCertificate) {
    this.caCertificate=caCertificate; return (A) this;
  }
  public Boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public Boolean hasNamespace() {
    return this.namespace != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public Boolean hasPort() {
    return this.port != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsolePluginProxyServiceFluentImpl that = (ConsolePluginProxyServiceFluentImpl) o;
    if (!java.util.Objects.equals(authorize, that.authorize)) return false;

    if (!java.util.Objects.equals(caCertificate, that.caCertificate)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(namespace, that.namespace)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authorize,  caCertificate,  name,  namespace,  port,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authorize != null) { sb.append("authorize:"); sb.append(authorize + ","); }
    if (caCertificate != null) { sb.append("caCertificate:"); sb.append(caCertificate + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (namespace != null) { sb.append("namespace:"); sb.append(namespace + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withAuthorize() {
    return withAuthorize(true);
  }
  
}
